@@ -59,10 +59,12 @@ json_schema_data_formats: Dict[str, Dict[str, Types]] = {
         'uuid4': Types.uuid4,
         'uuid5': Types.uuid5,
         'uri': Types.uri,
+        'uri-reference': Types.string,
         'hostname': Types.hostname,
         'ipv4': Types.ipv4,
         'ipv6': Types.ipv6,
         'decimal': Types.decimal,
+        'integer': Types.integer,
     },
     'boolean': {'default': Types.boolean},
     'object': {'default': Types.object},
